@@ -1,7 +1,7 @@
 use ockam_core::Result;
 use ockam_identity::Identity;
 use ockam_node::Context;
-use ockam_vault_sync_core::Vault;
+use ockam_vault::Vault;
 
 async fn test(ctx: Context) -> Result<()> {
     let vault = Vault::create();
