@@ -24,6 +24,19 @@ cfg_if! {
     }
 }
 
+#[derive(Clone, Debug, serde::Serialize, serde::Deserialize)]
+pub struct ExportedIdentity {
+    pub id: IdentityIdentifier,
+    pub contacts: Contacts,
+    pub change_history: IdentityChangeHistory,
+    // #[cfg(feature = "credentials")]
+    // #[serde(default)]
+    // pub rand_msg: Option<Message>,
+    // #[cfg(feature = "credentials")]
+    // #[serde(default)]
+    // pub credentials: Vec<IdentityCredential>,
+}
+
 /// Identity implementation
 pub struct IdentityState<V: IdentityVault> {
     id: IdentityIdentifier,
@@ -40,9 +53,10 @@ pub struct IdentityState<V: IdentityVault> {
 pub struct IdentityStateConst;
 
 impl IdentityStateConst {
-    /// Sha256 of that value is used as previous event id for first event in a [`Identity`]
+    /// Sha256 of that value is used as previous event id for first event in a
+    /// [`crate::Identity`]
     pub const NO_EVENT: &'static [u8] = "OCKAM_NO_EVENT".as_bytes();
-    /// Label for [`Identity`] update key
+    /// Label for [`crate::Identity`] update key
     pub const ROOT_LABEL: &'static str = "OCKAM_RK";
     /// Label for key used to issue credentials
     #[cfg(feature = "credentials")]
@@ -75,10 +89,35 @@ impl<V: IdentityVault> IdentityState<V> {
         }
     }
 
+    pub(crate) fn export(&self) -> ExportedIdentity {
+        ExportedIdentity {
+            id: self.id.clone(),
+            contacts: self.contacts.clone(),
+            change_history: self.change_history.clone(),
+            // #[cfg(feature = "credentials")]
+            // rand_msg: self.rand_msg.clone(),
+            // #[cfg(feature = "credentials")]
+            // credentials: self.credentials.clone(),
+        }
+    }
+
     pub(crate) fn change_history(&self) -> &IdentityChangeHistory {
         &self.change_history
     }
-
+    /// Create IdentityState
+    pub(crate) fn import(vault: V, identity: ExportedIdentity) -> Self {
+        Self {
+            id: identity.id,
+            change_history: identity.change_history,
+            contacts: identity.contacts,
+            vault,
+            #[cfg(feature = "credentials")]
+            rand_msg: Message::random(thread_rng()),
+            #[cfg(feature = "credentials")]
+            credentials: vec![],
+            lease: None,
+        }
+    }
     /// Create IdentityState
     pub(crate) async fn create(mut vault: V) -> Result<Self> {
         let initial_event_id = EventIdentifier::initial(&mut vault).await;
@@ -198,15 +237,17 @@ impl<V: IdentityVault> IdentityState<V> {
         self.change_history.get_public_key(&label)
     }
 
-    /// Generate Proof of possession of [`Identity`].
+    /// Generate Proof of possession of [`crate::Identity`].
+    ///
     /// channel_state should be tied to channel's cryptographical material (e.g. h value for Noise XX)
     pub async fn create_auth_proof(&mut self, channel_state: &[u8]) -> Result<AuthenticationProof> {
         let root_secret = self.get_root_secret_key().await?;
 
         Authentication::generate_proof(channel_state, &root_secret, &mut self.vault).await
     }
-    /// Verify Proof of possession of [`Identity`] with given [`IdentityIdentifier`].
-    /// channel_state should be tied to channel's cryptographical material (e.g. h value for Noise XX)
+    /// Verify Proof of possession of [`Identity`](crate::Identity) with given
+    /// [`IdentityIdentifier`]. channel_state should be tied to channel's
+    /// cryptographical material (e.g. h value for Noise XX)
     pub async fn verify_auth_proof(
         &mut self,
         channel_state: &[u8],
@@ -239,7 +280,7 @@ impl<V: IdentityVault> IdentityState<V> {
         Ok(self.change_history.as_ref().to_vec())
     }
 
-    /// Verify whole event chain of current [`Identity`]
+    /// Verify whole event chain of current [`Identity`](crate::Identity)
     pub async fn verify_changes(&mut self) -> Result<bool> {
         if !IdentityChangeHistory::check_consistency(&[], self.change_history().as_ref()) {
             return deny();
@@ -279,7 +320,7 @@ impl<V: IdentityVault> IdentityState<V> {
         ))
     }
 
-    pub async fn get_contact(&mut self, id: &IdentityIdentifier) -> Result<Option<Contact>> {
+    pub async fn get_contact(&self, id: &IdentityIdentifier) -> Result<Option<Contact>> {
         Ok(self.contacts.get(id).cloned())
     }
 
